searchData={"items":[{"type":"module","title":"AtomicWrites","doc":"Performs atomic file writes.","ref":"AtomicWrites.html"},{"type":"module","title":"Options - AtomicWrites","doc":"* `:path` (`t:String.t/0`) - Required. Path to the final file that is atomically written.\n\n* `:overwrite?` (`t:boolean/0`) - Overwrite the target file if it already exists? The default value is `true`.\n\n* `:tmp_dir` (`t:String.t/0`) - Directory in which the temporary files are written. The default value is `\".\"`.","ref":"AtomicWrites.html#module-options"},{"type":"module","title":"LWW Atomic Writes - AtomicWrites","doc":"```elixir\nAtomicWrites.write(\"Atomically written content.\", path: \"example.txt\")\n```","ref":"AtomicWrites.html#module-lww-atomic-writes"},{"type":"module","title":"FWW Atomic Writes - AtomicWrites","doc":"```elixir\nAtomicWrites.write(\"Atomically written content.\", path: \"example.txt\", overwrite?: false)\n```","ref":"AtomicWrites.html#module-fww-atomic-writes"},{"type":"module","title":"Serialized Atomic Writes - AtomicWrites","doc":"``` elixir\nalias AtomicWrites.AtomicFile\n\n{:ok, pid} = AtomicFile.start_link(path: \"example.txt\")\nAtomicFile.write(pid, \"Serialized, atomically written content.\")\n```","ref":"AtomicWrites.html#module-serialized-atomic-writes"},{"type":"module","title":"Installation - AtomicWrites","doc":"The package can be installed by adding `atomic_writes` to your list of\ndependencies in `mix.exs`:\n\n```elixir\ndef deps do\n[\n  {:atomic_writes, \"~> 1.0\"}\n]\nend\n```","ref":"AtomicWrites.html#module-installation"},{"type":"module","title":"License - AtomicWrites","doc":"AtomicWrites is released under the [`Apache License\n2.0`](https://github.com/elliotekj/atomic_writes/blob/main/LICENSE).","ref":"AtomicWrites.html#module-license"},{"type":"module","title":"About - AtomicWrites","doc":"This package was written by [Elliot Jackson](https://elliotekj.com).\n\n- Blog: [https://elliotekj.com](https://elliotekj.com)\n- Email: elliot@elliotekj.com","ref":"AtomicWrites.html#module-about"},{"type":"function","title":"AtomicWrites.write/2","doc":"Atomically write to the path.","ref":"AtomicWrites.html#write/2"},{"type":"module","title":"AtomicWrites.AtomicFile","doc":"Performs serialized atomic file writes.","ref":"AtomicWrites.AtomicFile.html"},{"type":"function","title":"AtomicWrites.AtomicFile.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"AtomicWrites.AtomicFile.html#child_spec/1"},{"type":"function","title":"AtomicWrites.AtomicFile.init/1","doc":"","ref":"AtomicWrites.AtomicFile.html#init/1"},{"type":"function","title":"AtomicWrites.AtomicFile.start_link/1","doc":"* `:path` (`t:String.t/0`) - Required. Path to the final file that is atomically written.\n\n* `:overwrite?` (`t:boolean/0`) - Overwrite the target file if it already exists? The default value is `true`.\n\n* `:tmp_dir` (`t:String.t/0`) - Directory in which the temporary files are written. The default value is `\".\"`.","ref":"AtomicWrites.AtomicFile.html#start_link/1"},{"type":"function","title":"AtomicWrites.AtomicFile.write/2","doc":"Atomically write to the path.","ref":"AtomicWrites.AtomicFile.html#write/2"},{"type":"extras","title":"AtomicWrites: LWW, FWW & Serialized Atomic File Writes in Elixir","doc":"# AtomicWrites: LWW, FWW & Serialized Atomic File Writes in Elixir\n\nPerform last-write-wins, first-write-wins or serialized atomic file writes in\nElixir with **AtomicWrites**. The basic idea is that writes are made to a\ntemporary file and then moved when the write is complete. By default, the\ntemporary write is made to the same file system (so that the move is also\natomic) and the move will overwrite any existing file (LWW). Both of these\noptions are configurable.","ref":"readme.html"},{"type":"extras","title":"LWW Atomic Writes - AtomicWrites: LWW, FWW & Serialized Atomic File Writes in Elixir","doc":"```elixir\nAtomicWrites.write(\"Atomically written content.\", path: \"example.txt\")\n```","ref":"readme.html#lww-atomic-writes"},{"type":"extras","title":"FWW Atomic Writes - AtomicWrites: LWW, FWW & Serialized Atomic File Writes in Elixir","doc":"```elixir\nAtomicWrites.write(\"Atomically written content.\", path: \"example.txt\", overwrite?: false)\n```","ref":"readme.html#fww-atomic-writes"},{"type":"extras","title":"Serialized Atomic Writes - AtomicWrites: LWW, FWW & Serialized Atomic File Writes in Elixir","doc":"``` elixir\nalias AtomicWrites.AtomicFile\n\n{:ok, pid} = AtomicFile.start_link(path: \"example.txt\")\nAtomicFile.write(pid, \"Serialized, atomically written content.\")\n```","ref":"readme.html#serialized-atomic-writes"},{"type":"extras","title":"Installation - AtomicWrites: LWW, FWW & Serialized Atomic File Writes in Elixir","doc":"The package can be installed by adding `atomic_writes` to your list of\ndependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:atomic_writes, \"~> 1.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - AtomicWrites: LWW, FWW & Serialized Atomic File Writes in Elixir","doc":"The documentation is published at  .","ref":"readme.html#documentation"},{"type":"extras","title":"License - AtomicWrites: LWW, FWW & Serialized Atomic File Writes in Elixir","doc":"AtomicWrites is released under the [`Apache License\n2.0`](https://github.com/elliotekj/atomic_writes/blob/main/LICENSE).","ref":"readme.html#license"},{"type":"extras","title":"About - AtomicWrites: LWW, FWW & Serialized Atomic File Writes in Elixir","doc":"This package was written by [Elliot Jackson](https://elliotekj.com).\n\n- Blog: [https://elliotekj.com](https://elliotekj.com)\n- Email: elliot@elliotekj.com","ref":"readme.html#about"}],"content_type":"text/markdown"}